import torch
import torch.nn as nn


class TabularFeatCombine(nn.Module):
    def __init__(self):
        super().__init__()
        pass

    def forward(self, x):
        pass


if __name__=='__main__':
    pass


